package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.CaMeterDMapper;
import com.ruoyi.ems.domain.CaMeterD;
import com.ruoyi.ems.service.ICaMeterDService;

/**
 * 碳计量日Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-12
 */
@Service
public class CaMeterDServiceImpl implements ICaMeterDService
{
    @Autowired
    private CaMeterDMapper caMeterDMapper;

    /**
     * 查询碳计量日
     * 
     * @param id 碳计量日主键
     * @return 碳计量日
     */
    @Override
    public CaMeterD selectCaMeterDById(Long id)
    {
        return caMeterDMapper.selectCaMeterDById(id);
    }

    /**
     * 查询碳计量日列表
     * 
     * @param caMeterD 碳计量日
     * @return 碳计量日
     */
    @Override
    public List<CaMeterD> selectCaMeterDList(CaMeterD caMeterD)
    {
        return caMeterDMapper.selectCaMeterDList(caMeterD);
    }

    /**
     * 新增碳计量日
     * 
     * @param caMeterD 碳计量日
     * @return 结果
     */
    @Override
    public int insertCaMeterD(CaMeterD caMeterD)
    {
        return caMeterDMapper.insertCaMeterD(caMeterD);
    }

    /**
     * 修改碳计量日
     * 
     * @param caMeterD 碳计量日
     * @return 结果
     */
    @Override
    public int updateCaMeterD(CaMeterD caMeterD)
    {
        return caMeterDMapper.updateCaMeterD(caMeterD);
    }

    /**
     * 批量删除碳计量日
     * 
     * @param ids 需要删除的碳计量日主键
     * @return 结果
     */
    @Override
    public int deleteCaMeterDByIds(Long[] ids)
    {
        return caMeterDMapper.deleteCaMeterDByIds(ids);
    }

    /**
     * 删除碳计量日信息
     * 
     * @param id 碳计量日主键
     * @return 结果
     */
    @Override
    public int deleteCaMeterDById(Long id)
    {
        return caMeterDMapper.deleteCaMeterDById(id);
    }
}
